
#include <glib.h>

// Disable the 'const' function attribute of the get_type() functions.
// GCC would optimize them out because we don't use the return value.
#undef  G_GNUC_CONST
#define G_GNUC_CONST /* empty */

#include <gstreamerbasemm/gst_wrap_init.h>
#include <glibmm/error.h>
#include <glibmm/object.h>

// #include the widget headers so that we can call the get_type() static methods:

#include "audioclock.h"
#include "audiofilter.h"
#include "audiosink.h"
#include "audiosrc.h"
#include "baseaudiosink.h"
#include "baseaudiosrc.h"
#include "cddabasesrc.h"
#include "videosink.h"
#include "colorbalance.h"
#include "colorbalancechannel.h"
#include "xoverlay.h"

extern "C"
{

//Declarations of the *_get_type() functions:


//Declarations of the *_error_quark() functions:

} // extern "C"


//Declarations of the *_Class::wrap_new() methods, instead of including all the private headers:


namespace GstBase { 

void gst_wrap_init()
{

// Map gtypes to gstreamermm wrapper-creation functions:

  // Register the gtkmm gtypes:

} // gst_wrap_init()

} //GstBase


